@@ -604,6 +604,14 @@ class CfnWorkGroup(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrCreationTime"))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="attrEffectiveEngineVersion")
+    def attr_effective_engine_version(self) -> builtins.str:
+        '''
+        :cloudformationAttribute: EffectiveEngineVersion
+        '''
+        return typing.cast(builtins.str, jsii.get(self, "attrEffectiveEngineVersion"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
@@ -765,6 +773,62 @@ class CfnWorkGroup(
                 k + "=" + repr(v) for k, v in self._values.items()
             )
 
+    @jsii.data_type(
+        jsii_type="@aws-cdk/aws-athena.CfnWorkGroup.EngineVersionProperty",
+        jsii_struct_bases=[],
+        name_mapping={
+            "effective_engine_version": "effectiveEngineVersion",
+            "selected_engine_version": "selectedEngineVersion",
+        },
+    )
+    class EngineVersionProperty:
+        def __init__(
+            self,
+            *,
+            effective_engine_version: typing.Optional[builtins.str] = None,
+            selected_engine_version: typing.Optional[builtins.str] = None,
+        ) -> None:
+            '''
+            :param effective_engine_version: ``CfnWorkGroup.EngineVersionProperty.EffectiveEngineVersion``.
+            :param selected_engine_version: ``CfnWorkGroup.EngineVersionProperty.SelectedEngineVersion``.
+
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-engineversion.html
+            '''
+            self._values: typing.Dict[str, typing.Any] = {}
+            if effective_engine_version is not None:
+                self._values["effective_engine_version"] = effective_engine_version
+            if selected_engine_version is not None:
+                self._values["selected_engine_version"] = selected_engine_version
+
+        @builtins.property
+        def effective_engine_version(self) -> typing.Optional[builtins.str]:
+            '''``CfnWorkGroup.EngineVersionProperty.EffectiveEngineVersion``.
+
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-engineversion.html#cfn-athena-workgroup-engineversion-effectiveengineversion
+            '''
+            result = self._values.get("effective_engine_version")
+            return typing.cast(typing.Optional[builtins.str], result)
+
+        @builtins.property
+        def selected_engine_version(self) -> typing.Optional[builtins.str]:
+            '''``CfnWorkGroup.EngineVersionProperty.SelectedEngineVersion``.
+
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-engineversion.html#cfn-athena-workgroup-engineversion-selectedengineversion
+            '''
+            result = self._values.get("selected_engine_version")
+            return typing.cast(typing.Optional[builtins.str], result)
+
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
+            return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
+            return not (rhs == self)
+
+        def __repr__(self) -> str:
+            return "EngineVersionProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
+
     @jsii.data_type(
         jsii_type="@aws-cdk/aws-athena.CfnWorkGroup.ResultConfigurationProperty",
         jsii_struct_bases=[],
@@ -919,6 +983,7 @@ class CfnWorkGroup(
         name_mapping={
             "bytes_scanned_cutoff_per_query": "bytesScannedCutoffPerQuery",
             "enforce_work_group_configuration": "enforceWorkGroupConfiguration",
+            "engine_version": "engineVersion",
             "publish_cloud_watch_metrics_enabled": "publishCloudWatchMetricsEnabled",
             "requester_pays_enabled": "requesterPaysEnabled",
             "result_configuration": "resultConfiguration",
@@ -930,6 +995,7 @@ class CfnWorkGroup(
             *,
             bytes_scanned_cutoff_per_query: typing.Optional[jsii.Number] = None,
             enforce_work_group_configuration: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
+            engine_version: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.EngineVersionProperty"]] = None,
             publish_cloud_watch_metrics_enabled: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
             requester_pays_enabled: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
             result_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.ResultConfigurationProperty"]] = None,
@@ -937,6 +1003,7 @@ class CfnWorkGroup(
             '''
             :param bytes_scanned_cutoff_per_query: ``CfnWorkGroup.WorkGroupConfigurationProperty.BytesScannedCutoffPerQuery``.
             :param enforce_work_group_configuration: ``CfnWorkGroup.WorkGroupConfigurationProperty.EnforceWorkGroupConfiguration``.
+            :param engine_version: ``CfnWorkGroup.WorkGroupConfigurationProperty.EngineVersion``.
             :param publish_cloud_watch_metrics_enabled: ``CfnWorkGroup.WorkGroupConfigurationProperty.PublishCloudWatchMetricsEnabled``.
             :param requester_pays_enabled: ``CfnWorkGroup.WorkGroupConfigurationProperty.RequesterPaysEnabled``.
             :param result_configuration: ``CfnWorkGroup.WorkGroupConfigurationProperty.ResultConfiguration``.
@@ -948,6 +1015,8 @@ class CfnWorkGroup(
                 self._values["bytes_scanned_cutoff_per_query"] = bytes_scanned_cutoff_per_query
             if enforce_work_group_configuration is not None:
                 self._values["enforce_work_group_configuration"] = enforce_work_group_configuration
+            if engine_version is not None:
+                self._values["engine_version"] = engine_version
             if publish_cloud_watch_metrics_enabled is not None:
                 self._values["publish_cloud_watch_metrics_enabled"] = publish_cloud_watch_metrics_enabled
             if requester_pays_enabled is not None:
@@ -975,6 +1044,17 @@ class CfnWorkGroup(
             result = self._values.get("enforce_work_group_configuration")
             return typing.cast(typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]], result)
 
+        @builtins.property
+        def engine_version(
+            self,
+        ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.EngineVersionProperty"]]:
+            '''``CfnWorkGroup.WorkGroupConfigurationProperty.EngineVersion``.
+
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfiguration.html#cfn-athena-workgroup-workgroupconfiguration-engineversion
+            '''
+            result = self._values.get("engine_version")
+            return typing.cast(typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.EngineVersionProperty"]], result)
+
         @builtins.property
         def publish_cloud_watch_metrics_enabled(
             self,
@@ -1025,6 +1105,7 @@ class CfnWorkGroup(
         name_mapping={
             "bytes_scanned_cutoff_per_query": "bytesScannedCutoffPerQuery",
             "enforce_work_group_configuration": "enforceWorkGroupConfiguration",
+            "engine_version": "engineVersion",
             "publish_cloud_watch_metrics_enabled": "publishCloudWatchMetricsEnabled",
             "remove_bytes_scanned_cutoff_per_query": "removeBytesScannedCutoffPerQuery",
             "requester_pays_enabled": "requesterPaysEnabled",
@@ -1037,6 +1118,7 @@ class CfnWorkGroup(
             *,
             bytes_scanned_cutoff_per_query: typing.Optional[jsii.Number] = None,
             enforce_work_group_configuration: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
+            engine_version: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.EngineVersionProperty"]] = None,
             publish_cloud_watch_metrics_enabled: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
             remove_bytes_scanned_cutoff_per_query: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
             requester_pays_enabled: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
@@ -1045,6 +1127,7 @@ class CfnWorkGroup(
             '''
             :param bytes_scanned_cutoff_per_query: ``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.BytesScannedCutoffPerQuery``.
             :param enforce_work_group_configuration: ``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.EnforceWorkGroupConfiguration``.
+            :param engine_version: ``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.EngineVersion``.
             :param publish_cloud_watch_metrics_enabled: ``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.PublishCloudWatchMetricsEnabled``.
             :param remove_bytes_scanned_cutoff_per_query: ``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.RemoveBytesScannedCutoffPerQuery``.
             :param requester_pays_enabled: ``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.RequesterPaysEnabled``.
@@ -1057,6 +1140,8 @@ class CfnWorkGroup(
                 self._values["bytes_scanned_cutoff_per_query"] = bytes_scanned_cutoff_per_query
             if enforce_work_group_configuration is not None:
                 self._values["enforce_work_group_configuration"] = enforce_work_group_configuration
+            if engine_version is not None:
+                self._values["engine_version"] = engine_version
             if publish_cloud_watch_metrics_enabled is not None:
                 self._values["publish_cloud_watch_metrics_enabled"] = publish_cloud_watch_metrics_enabled
             if remove_bytes_scanned_cutoff_per_query is not None:
@@ -1086,6 +1171,17 @@ class CfnWorkGroup(
             result = self._values.get("enforce_work_group_configuration")
             return typing.cast(typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]], result)
 
+        @builtins.property
+        def engine_version(
+            self,
+        ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.EngineVersionProperty"]]:
+            '''``CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.EngineVersion``.
+
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-athena-workgroup-workgroupconfigurationupdates.html#cfn-athena-workgroup-workgroupconfigurationupdates-engineversion
+            '''
+            result = self._values.get("engine_version")
+            return typing.cast(typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkGroup.EngineVersionProperty"]], result)
+
         @builtins.property
         def publish_cloud_watch_metrics_enabled(
             self,
